<?php
namespace Teknisa\SUP\Modules\Fornecimento\Modules\Relatorios\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Teknisa\SUP\Util\SupUtilities;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Sup02500PrazoMedioComprasController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $SupUtilities;
    protected $crudService;
    protected $dataSourceName = "sup02500_prazo_medio_compras";

    public function __construct($reportService, $qr2Strategy, $SupUtilities, $crudService)
    {
        $this->qr2Strategy         = $qr2Strategy;
        $this->reportService       = $reportService;
        $this->SupUtilities        = $SupUtilities;
        $this->crudService         = $crudService;
    }
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $row['DTINIC'] = $row['INTERVALO_DATA']["start"];
        $row['DTFIM'] = $row['INTERVALO_DATA']["end"];
      
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $this->reportMapping[$this->stNomeRel] =
            array (
            'strategy' => 'QR2',
            'parameterMapping' =>
            array (
                "FORNECEDOR"    => "L_CDFORNECED",
                "CDFORNECED1"   => "L_CDFORNECED1",
                "TXDTINIC"      => "P_DTINICIAL",
                "TXDTFIM"       => "P_DTFINAL",
                "CDPRODINI"     => "P_CDPRODINIC",
                "CDPRODFIM"     => "P_CDPRODFIN",
                "DTINIC"        => "P_CDDATINIC",
                "DTFIM"         => "P_CDDATFIN",
                "P_COMPRADOR"   => "P_COMPRADOR"    
            ),
        );
        
        print_r($row);
    }
    
    public function find (DTO\Request\Filter $request, DTO\Response $response){
        
        $oldFilterCriteria = $request->getFilterCriteria();
        $filters = $oldFilterCriteria->getConditions();
        $item_list = array();
        $params = [
            'L_CDFORNECED',
            'P_COMPRADOR',
            'P_CDARVPRODINIC',
            'P_CDARVPRODFIN',
            'P_CDDATINIC',
            'P_CDDATFIN',
            'P_CONSIDERA'
        ];

        $queryParams = array();
        
        $NRLISTA_CDFORNECEDOR = null;
        $EXISTE_COMPRADOR = false;
        
        foreach($filters as $filter){
           if($filter['columnName'] === 'CDFORNECED'){
               
               $NRLISTA_CDFORNECEDOR = $this->SupUtilities->insertLista($filter['value']);
               
               $queryParams[] = $this->setTemplate('L_CDFORNECED', $NRLISTA_CDFORNECEDOR);
           
               
            }else if($filter['columnName'] === 'P_COMPRADOR'){
                $EXISTE_COMPRADOR = true;
                if(count($filter['value']) > 0){
                    $p_comprador = implode('_', $filter['value']); 
                }else {
                    $p_comprador = 'T';
                }
               
               $queryParams[] = $this->setTemplate($filter['columnName'], $p_comprador);
               
            } else if($filter['columnName'] === 'INTERVALO_DATA'){
               
               $queryParams[] = $this->setTemplate('P_CDDATINIC',$filter['value'][0]);
               $queryParams[] = $this->setTemplate('P_CDDATFIN',$filter['value'][1]);
               
            } else if($filter['columnName'] === 'CDARVPRODINI'){ 
                
                $queryParams[] = $this->setTemplate('P_CDARVPRODINIC' , $filter['value']); 
                
            } else if($filter['columnName'] === 'CDARVPRODFIM'){
               
                $cdProd = str_pad($filter['value'], 20, "z", STR_PAD_RIGHT);
               
                $queryParams[] = $this->setTemplate('P_CDARVPRODFIN' , $cdProd); 
                
            } else if($filter['columnName'] === 'TIPO') {
                
                $queryParams[] = $this->setTemplate('P_CONSIDERA', $filter['value']);
                
            } else {
               $queryParams[] = $filter;
           }
           
           //print_r($queryParams);
        }
        
        if(!$EXISTE_COMPRADOR){
            $queryParams[] = $this->setTemplate('P_COMPRADOR', 'T');
            
        }
        
        $filterCriteria = new FilterCriteria($this->dataSourceName, $queryParams, $oldFilterCriteria->getPage(), $oldFilterCriteria->getPageSize());
        $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
        $filterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, $params);
    
        $this->crudService->find($response, $filterCriteria);
    
        if($NRLISTA_CDFORNECEDOR){
            $this->SupUtilities->deleteLista($NRLISTA_CDFORNECEDOR);
        }
    }
    
    protected function setTemplate($name, $value, $operator = '=') {
        return array(
            'columnName' => $name,
            'operator'   => $operator,
            'value'      => $value
        
        );
    }
}